'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

var _Rx = require('rxjs/Rx');

var _Rx2 = _interopRequireDefault(_Rx);

var _prettierEslint = require('prettier-eslint');

var _prettierEslint2 = _interopRequireDefault(_prettierEslint);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var rxGlob = _Rx2.default.Observable.bindNodeCallback(_glob2.default);
var rxReadFile = _Rx2.default.Observable.bindNodeCallback(_fs2.default.readFile);
var rxWriteFile = _Rx2.default.Observable.bindNodeCallback(_fs2.default.writeFile);

exports.default = formatFilesFromArgv;


function formatFilesFromArgv(_ref) {
  var fileGlobs = _ref._,
      enableLog = _ref.log,
      eslintPath = _ref.eslintPath,
      prettierPath = _ref.prettierPath;

  var options = { disableLog: !enableLog, eslintPath, prettierPath };
  var concurrentGlobs = 3;
  var concurrentFormats = 10;
  return _Rx2.default.Observable.from(fileGlobs).mergeMap(getFilesFromGlob, null, concurrentGlobs).concatAll().distinct().mergeMap(function (filePath) {
    return formatFile(filePath, options);
  }, null, concurrentFormats).toArray().toPromise().then(function (allWrittenFiles) {
    /* eslint no-console:0 */
    var count = _chalk2.default.bold(allWrittenFiles.length);
    console.log(`${ _chalk2.default.green('success') } formatting ${ count } files with prettier-eslint ✨`);
    return allWrittenFiles;
  });
}

function getFilesFromGlob(fileGlob) {
  var globOptions = { ignore: [] };
  if (!fileGlob.includes('node_modules')) {
    // basically, we're going to protect you from doing something
    // not smart unless you explicitly include it in your glob
    globOptions.ignore.push('**/node_modules/**');
  }
  return rxGlob(fileGlob, globOptions);
}

function formatFile(filePath, options) {
  return rxReadFile(filePath, 'utf8').map(function (text) {
    return (0, _prettierEslint2.default)(_extends({ text, filePath }, options));
  }).mergeMap(function (formatted) {
    return rxWriteFile(filePath, formatted).map(function () {
      return filePath;
    });
  });
}